@@ -12,7 +12,7 @@ Python libraries, though it does make heavy use of external packaging commands.
 Visit <https://github.com/datalad/datalad-installer> for more information.
 """
 
-__version__ = "0.8.1"
+__version__ = "0.8.2"
 __author__ = "The DataLad Team and Contributors"
 __author_email__ = "team@datalad.org"
 __license__ = "MIT"
@@ -1870,7 +1870,9 @@ class DataladGitAnnexBuildInstaller(Installer):
             raise MethodNotSupportedError(f"{SYSTEM} OS not supported")
 
     @staticmethod
-    def download(ostype: str, target_dir: Path, _version: Optional[str]) -> None:
+    def download(
+        ostype: str, target_dir: Path, version: Optional[str]  # noqa: U100
+    ) -> None:
         """
         Download & unzip the artifact from the latest successful build of
         datalad/git-annex for the given OS in the given directory
@@ -1890,7 +1892,9 @@ class DataladGitAnnexLatestBuildInstaller(DataladGitAnnexBuildInstaller):
     NAME = "datalad/git-annex"
 
     @staticmethod
-    def download(ostype: str, target_dir: Path, _version: Optional[str]) -> None:
+    def download(
+        ostype: str, target_dir: Path, version: Optional[str]  # noqa: U100
+    ) -> None:
         """
         Download & unzip the artifact from the latest build of
         datalad/git-annex for the given OS in the given directory
@@ -2250,7 +2254,7 @@ class GitHubClient:
             archive_download_url = self.get_archive_download_url(artifacts_url)
             if archive_download_url is not None:
                 log.info("Downloading artifact package from %s", archive_download_url)
-                download_zipfile(archive_download_url, target_dir)
+                download_zipfile(archive_download_url, target_dir, headers=self.headers)
                 return
         else:
             raise RuntimeError("No workflow runs with artifacts found!")
@@ -2272,7 +2276,7 @@ class GitHubClient:
             archive_download_url = self.get_archive_download_url(artifacts_url)
             if archive_download_url is not None:
                 log.info("Downloading artifact package from %s", archive_download_url)
-                download_zipfile(archive_download_url, target_dir)
+                download_zipfile(archive_download_url, target_dir, headers=self.headers)
                 return
         else:
             raise RuntimeError("No workflow runs with artifacts found!")
